import { getWasmInlined } from './wasm.mjs';
import { g as getHighlighterCore, i as isPlaintext, t as toArray } from './chunks/core.mjs';
export { l as loadWasm } from './chunks/core.mjs';
import { bundledLanguages } from './langs.mjs';
export { bundledLanguagesAlias, bundledLanguagesBase } from './langs.mjs';
import { bundledThemes } from './themes.mjs';

async function getHighlighter(options = {}) {
  var _a, _b;
  function resolveLang(lang) {
    if (typeof lang === "string") {
      if (isPlaintext(lang))
        return [];
      const bundle = bundledLanguages[lang];
      if (!bundle)
        throw new Error(`[shikiji] Language \`${lang}\` is not built-in.`);
      return bundle;
    }
    return lang;
  }
  function resolveTheme(theme) {
    if (typeof theme === "string") {
      const bundle = bundledThemes[theme];
      if (!bundle)
        throw new Error(`[shikiji] Theme \`${theme}\` is not built-in.`);
      return bundle;
    }
    return theme;
  }
  const _themes = ((_a = options.themes) != null ? _a : []).map(resolveTheme);
  const langs = ((_b = options.langs) != null ? _b : []).map(resolveLang);
  const core = await getHighlighterCore({
    ...options,
    themes: _themes,
    langs,
    loadWasm: getWasmInlined
  });
  return {
    ...core,
    codeToHtml(code, options2 = {}) {
      return core.codeToHtml(code, options2);
    },
    loadLanguage(...langs2) {
      return core.loadLanguage(...langs2.map(resolveLang));
    },
    loadTheme(...themes) {
      return core.loadTheme(...themes.map(resolveTheme));
    }
  };
}

let _shiki;
async function getShikiWithThemeLang(options) {
  if (!_shiki) {
    _shiki = getHighlighter({
      themes: toArray(options.theme),
      langs: toArray(options.lang)
    });
    return _shiki;
  } else {
    const s = await _shiki;
    await Promise.all([
      s.loadTheme(...toArray(options.theme)),
      s.loadLanguage(...toArray(options.lang))
    ]);
    return s;
  }
}
async function codeToHtml(code, options) {
  const shiki = await getShikiWithThemeLang(options);
  return shiki.codeToHtml(code, options);
}
async function codeToThemedTokens(code, options) {
  const shiki = await getShikiWithThemeLang(options);
  return shiki.codeToThemedTokens(code, options);
}
async function codeToHtmlDualThemes(code, options) {
  const shiki = await getShikiWithThemeLang({
    lang: options.lang,
    theme: Object.values(options.themes).filter(Boolean)
  });
  return shiki.codeToHtmlDualThemes(code, options);
}

export { bundledLanguages, bundledThemes, codeToHtml, codeToHtmlDualThemes, codeToThemedTokens, getHighlighter, getHighlighterCore, getWasmInlined };
